ButtonComponent class Models

A clickable button.

Inheritance

Properties

customId String?
This component's custom ID.
final
emoji Emoji?
The Emoji displayed on this button.
final
hashCode int
The hash code for this object.
no setterinherited
id int
An identifier for this component.
finalinherited
isDisabled bool?
Whether this button is disabled.
final
label String?
The label displayed on this button.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skuId Snowflake?
The purchasable SKU ID, if this button has ButtonStyle.premium style.
final
style ButtonStyle
The style of this button.
final
type ComponentType
The type of this component.
no setteroverride
url Uri?
The URL this button redirects to, if this button is a URL button.
final

Methods

defaultToString() String
Same as toString, but only called when dart:mirrors is not available.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited