Properties
-
answerId
→ int
-
The ID of the answer.
final
-
count
→ int
-
The number of votes for this answer.
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
me
→ bool
-
Whether the current user voted for this answer.
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
defaultToString()
→ String
-
Same as
toString, but only called when dart:mirrors is not available.
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited