PollResults class Models

In a nutshell, this contains the number of votes for each answer. Due to the intricacies of counting at scale, while a poll is in progress the results may not be perfectly accurate. They usually are accurate, and shouldn't deviate significantly -- it's just difficult to make guarantees. To compensate for this, after a poll is finished there is a background job which performs a final, accurate tally of votes. This tally has concluded once PollResults.isFinalized is true. If PollResults.answerCounts does not contain an entry for a particular answer, then there are no votes for that answer.

External references:

Properties

answerCounts List<PollAnswerCount>
The counts for each answer.
final
hashCode int
The hash code for this object.
no setterinherited
isFinalized bool
Whether the votes have been precisely counted.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

defaultToString() String
Same as toString, but only called when dart:mirrors is not available.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited