RecurrenceRule class Models

Properties

byMonth List<RecurrenceRuleMonth>?
The specific months the event recurs on.
final
byMonthDay List<int>?
The specific days within a month the event recurs on.
final
byNWeekday List<RecurrenceRuleNWeekday>?
The specific days within a specific week the event recurs on.
final
byWeekday List<RecurrenceRuleWeekday>?
The specific days within a week the event recurs on.
final
byYearDay List<int>?
The specific days within a year the event recurs on.
final
count int?
The total number of times the event is allowed to recur before stopping.
final
end DateTime?
The end of the interval within which the event recurs.
final
frequency RecurrenceRuleFrequency
The frequency this rule applies to.
final
hashCode int
The hash code for this object.
no setterinherited
interval int
The spacing between each recurrence of the event, in multiples of frequency.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start DateTime
The start of the interval within which the event recurs.
final

Methods

defaultToString() String
Same as toString, but only called when dart:mirrors is not available.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited