ResolvedData class Models
A mapping of IDs to entities.
Properties
-
attachments
→ Map<
Snowflake, Attachment> ? -
A mapping of attachment ID to Attachment.
final
-
channels
→ Map<
Snowflake, PartialChannel?> ? -
A mapping of channel ID to PartialChannel.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
members
→ Map<
Snowflake, Member> ? -
A mapping of member ID to Member.
final
-
messages
→ Map<
Snowflake, Message?> ? -
A mapping of message ID to Message.
final
-
roles
→ Map<
Snowflake, Role> ? -
A mapping of role ID to Role.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
users
→ Map<
Snowflake, User> ? -
A mapping of user ID to User.
final
Methods
-
defaultToString(
) → String -
Same as
toString, but only called when dart:mirrors is not available.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited