SubmittedSelectMenuComponent class Models

A SelectMenuComponent received in an Interaction.

Inheritance

Properties

channels List<PartialChannel>?
The selected channels.
no setter
customId String
The custom ID of this select menu.
final
hashCode int
The hash code for this object.
no setterinherited
id int
An identifier for this component.
finalinherited
manager MessageManager
final
members List<PartialMember>?
The selected members.
no setter
roles List<PartialRole>?
The selected roles.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type ComponentType
The type of this component.
final
users List<PartialUser>?
The selected users.
no setter
values List<String>
The values selected by the user.
final

Methods

defaultToString() String
Same as toString, but only called when dart:mirrors is not available.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited