lastPinTimestamp property
DateTime?
get
lastPinTimestamp
The time at which the last message was pinned, or null if no messages have been pinned.
Implementation
DateTime? get lastPinTimestamp;
The time at which the last message was pinned, or null if no messages have been pinned.
DateTime? get lastPinTimestamp;