uhxx
A complete, robust and efficient wrapper around Discord's API for bots & applications.
To get started using uhxx, follow our getting started guide to write your first bot.
If you're already familiar with Discord's API, here's a quick example to get you started:
import 'package:uhxx/uhxx.dart';
void main() async {
final client = await Uhxx.connectGateway('<TOKEN>', GatewayIntents.allUnprivileged);
final botUser = await client.users.fetchCurrentUser();
client.onMessageCreate.listen((event) async {
if (event.mentions.contains(botUser)) {
await event.message.channel.sendMessage(MessageBuilder(
content: 'You mentioned me!',
referencedMessage: MessageReferenceBuilder.reply(messageId: event.message.id),
));
}
});
}
Other uhxx packages
- uhxx_commands: A command framework for handling both simple & complex commands.
- uhxx_extensions: Pagination, emoji utilities and other miscellaneous helpers for developing bots using uhxx.
- uhxx_lavalink: Lavalink support for playing audio in voice channels.
More examples
- More examples can be found in our GitHub repository here.
- Running on Dart is a complete example of a bot written with uhxx.
Additional documentation & help
The API documentation for the latest stable version can be found on pub.
Docs and wiki
Tutorials and wiki articles are hosted here.
Official uhxx Discord server
Our Discord server is where you can get help for any uhxx packages, as well as release announcements and discussions about the library.
Discord API docs
Discord's API documentation details what uhxx implements & provides more detailed explanations of certain topics.
Discord API Server
The unofficial guild for Discord Bot developers. To get help with uhxx check #dart_uhxx channel.
Pub.dev docs
The dartdocs page will always have the documentation for the latest release.
Contributing to Uhxx
Read the contributing document
Credits
- Thanks to Hackzzila's for nyx, the original project uhxx was forked from.