EmbedVideo class Models
A video in an Embed.
External references:
- Discord API Reference: https://discord.com/developers/docs/resources/channel#embed-object-embed-video-structure
Properties
- contentType → String?
-
The content type (MIME type) of this video.
final
- description → String?
-
A description of the video.
final
- flags → EmbedMediaFlags?
-
Flags applied to this video.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int?
-
The height of the video in pixels.
final
- placeholder → String?
-
A Thumbhash placeholder for this video.
final
- placeholderVersion → int?
-
The version of the placeholder.
final
- proxiedUrl → Uri?
-
A proxied URL of this video.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → Uri?
-
The URL of this video.
final
- width → int?
-
The width of the video in pixels.
final
Methods
-
defaultToString(
) → String -
Same as
toString, but only called when dart:mirrors is not available.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited