FileUploadComponent class
Models
Properties
-
customId
→ String
-
The custom id for this component
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
id
→ int
-
An identifier for this component.
finalinherited
-
isRequired
→ bool?
-
Whether this component is required when in a modal.
final
-
maxValues
→ int?
-
The maximum number of files the user can upload. (default 1, max 10)
final
-
minValues
→ int?
-
The minimum number of files the user must upload. (default 1, min 0)
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
type
→ ComponentType
-
The type of this component.
no setteroverride
Methods
-
defaultToString()
→ String
-
Same as
toString, but only called when dart:mirrors is not available.
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited