- Inheritance
-
- Object
- ReadOnlyManager<
SoundboardSound> - Manager<
SoundboardSound> - SoundboardManager
- Implementers
Constructors
-
SoundboardManager(CacheConfig<
SoundboardSound> config, UhxxRest client, {required String identifier})
Properties
-
cache
→ Cache<
SoundboardSound> -
The cache for this manager.
finalinherited
- client → UhxxRest
-
The client this manager belongs to.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
create(
covariant CreateBuilder< SoundboardSound> builder) → Future<SoundboardSound> -
Create a new instance of the type of this manager.
inherited
-
delete(
Snowflake id) → Future< void> -
Delete the item with the given
idfrom the API.inherited -
fetch(
Snowflake id) → Future< SoundboardSound> -
Fetch the item with the given
idfrom the API.inherited -
get(
Snowflake id) → Future< SoundboardSound> -
Get an item by its
idfrom the cache if it exists, else fetch it from the API.inherited -
list(
) → Future< List< SoundboardSound> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parse(
Map< String, Object?> raw) → SoundboardSound -
Parse the
rawdata received from the API into an instance of the type of this manager.override -
toString(
) → String -
A string representation of this object.
inherited
-
update(
Snowflake id, covariant UpdateBuilder< SoundboardSound> builder) → Future<SoundboardSound> -
Update the item with the given
idin the API.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
Snowflake id) → WritableSnowflakeEntity< SoundboardSound> -
Return a partial instance of the entity with ID
idcontaining no data.inherited