VoiceChannelEffectSendEvent class Events
Emitted when someone sends an effect, such as an emoji reaction or a soundboard sound, in a voice channel the current user is connected to.
- Inheritance
-
- Object
- GatewayEvent
- DispatchEvent
- VoiceChannelEffectSendEvent
Properties
- animationId → int?
-
The ID of the emoji animation, for emoji reaction and soundboard effects.
final
- animationType → AnimationType?
-
The type of emoji animation, for emoji reaction and soundboard effects.
final
- channel → PartialChannel
-
The channel this effect was sent in.
no setter
- channelId → Snowflake
-
The ID of the channel this effect was sent in.
final
- emoji → Emoji?
-
The emoji sent, for emoji reaction and soundboard effects.
final
- gateway → Gateway
-
The gateway that handled this event.
finalinherited
- guild → PartialGuild
-
The guild this effect was sent in.
no setter
- guildId → Snowflake
-
The ID of the guild this effect was sent in.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- opcode → Opcode
-
The opcode of this event.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- soundId → Snowflake?
-
The ID of the soundboard sound, for soundboard effects.
final
- soundVolume → double?
-
The volume of the soundboard sound, from 0 to 1, for soundboard effects.
final
- user → PartialUser
-
The user who sent this effect.
no setter
- userId → Snowflake
-
The ID of the user who sent this effect.
final
Methods
-
defaultToString(
) → String -
Same as
toString, but only called when dart:mirrors is not available.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited